@@ -1,11 +1,12 @@
 SpatialPixelsDataFrame = function(points, data, 
 		tolerance = sqrt(.Machine$double.eps), 
-		proj4string = CRS(as.character(NA))) {
+		proj4string = CRS(as.character(NA)), round=NULL, fuzz.tol=3) {
 	if (is.null(points))
 		stop("points argument is NULL")
 	if (!is(points, "SpatialPoints"))
 		points = SpatialPoints(points, proj4string = proj4string)
-	points = SpatialPixels(points, tolerance)
+	points = SpatialPixels(points, tolerance=tolerance, round=round, 
+		fuzz.tol=fuzz.tol)
 	new("SpatialPixelsDataFrame", points, data = data)
 }
 
@@ -65,6 +66,11 @@ setIs("SpatialPixelsDataFrame", "SpatialPointsDataFrame",
 	}, replace = function(obj, value) stop("no replace function for this coercion")
 )
 
+as.SpatialPolygonsDataFrame.SpatialPixelsDataFrame = function(from)
+	SpatialPolygonsDataFrame(as(from, "SpatialPolygons"), from@data, FALSE)
+setAs("SpatialPixelsDataFrame", "SpatialPolygonsDataFrame",
+	as.SpatialPolygonsDataFrame.SpatialPixelsDataFrame)
+
 as.matrix.SpatialPixelsDataFrame = function(x, ...) {
 	# fullgrid(x) = TRUE
 	x = as(x, "SpatialGridDataFrame")
